<template>
    <div
        element-loading-text="数据加载中..."
        element-loading-spinner="el-icon-loading"
        element-loading-background="rgba(255,255,255, 0.5)"
        v-loading.fullscreen.lock="loading"
    >
        <el-dialog
            v-dialogDrag
            :title="type + '人员备案'"
            :visible="visible"
            :before-close="handleClose"
            :close-on-click-modal="false"
            v-if="visible"
            width="50%"
            top="6vh"
            :class="[loading ? 'dialog-box' : '']"
        >
            <div>
                <el-form
                    ref="form"
                    :rules="rules"
                    :model="formData"
                    label-width="100px"
                >
                    <el-row>
                        <el-col :span="12">
                            <el-form-item label="姓名" prop="name">
                                <el-input
                                    style="width: 100%"
                                    clearable
                                    v-model="formData.name"
                                    placeholder="请输入姓名"
                                ></el-input>
                            </el-form-item>
                        </el-col>
                        <el-col :span="12">
                            <el-form-item label="联系电话" prop="phone">
                                <el-input
                                    clearable
                                    style="width: 100%"
                                    v-model="formData.phone"
                                    oninput="value=value.replace(/[^0-9]/g,'')"
                                    maxlength="11"
                                    placeholder="请输入联系电话"
                                ></el-input>
                            </el-form-item>
                        </el-col>
                    </el-row>
                    <el-row>
                        <el-col :span="12">
                            <el-form-item label="行政区划" prop="areaCode">
                                <el-cascader
                                    style="width: 100%"
                                    v-model="areaCode"
                                    :props="{label: 'name', value: 'code'}"
                                    @change="handleChange"
                                    :options="options"
                                    placeholder="请选择行政区划"
                                ></el-cascader>
                            </el-form-item>
                        </el-col>
                        <el-col :span="12">
                            <el-form-item
                                label="广场舞地点"
                                prop="squareTeamList"
                            >
                                <el-select
                                    popper-class="square-select"
                                    style="width: 100%"
                                    :popper-append-to-body="false"
                                    value-key="squareLocationId"
                                    @focus="handleSearchPlaces"
                                    v-model="formData.squareTeamList"
                                    multiple
                                    placeholder="请选择广场舞地点"
                                >
                                    <el-option
                                        v-for="item in formData.squareTeamList"
                                        :key="item.squareLocationId"
                                        :label="item.squareLocationName"
                                        :value="item"
                                    >
                                    </el-option>
                                </el-select>
                            </el-form-item>
                        </el-col>
                    </el-row>
                </el-form>
            </div>
            <div
                slot="footer"
                class="dialog-footer"
                :style="loading ? 'position: relative;z-index: -1;' : ''"
            >
                <el-button @click="handleClose">取消</el-button>
                <el-button
                    type="primary"
                    @click="handleSave"
                    :loading="btnLoading"
                    >确定</el-button
                >
            </div>
        </el-dialog>
        <placesDialog
            ref="placesDialog"
            :isMultiple="true"
            @changePlaces="changePlaces"
        />
    </div>
</template>
        
<script>
import utils from '@/utils.js'
import Personal from '@/api/basicConfiguration/Personal'
import Team from '@/api/basicConfiguration/Team'
import placesDialog from './placesDialog.vue'

export default {
    props: {},
    name: 'PersonalDialog',
    components: {placesDialog},
    data() {
        const validatePhone = (rule, value, callback) => {
            const regExp = /^1[3|4|5|7|8|9][0-9]{9}$/
            if (!regExp.test(value)) {
                callback(new Error('请输入正确的手机号'))
            } else {
                callback()
            }
        }
        const validateSquare = (rule, value, callback) => {
            console.log(value)
            if (value.length) {
                callback()
            } else {
                callback(new Error('请选择广场舞地点'))
            }
        }
        return {
            visible: false,
            loading: false,
            rules: {
                name: [
                    {
                        required: true,
                        message: '请输入姓名',
                        trigger: 'blur',
                    },
                ],
                phone: [
                    {
                        required: true,
                        message: '请输入联系电话',
                        trigger: 'blur',
                    },
                    {
                        validator: validatePhone,
                        tirgger: 'blur',
                    },
                ],
                areaCode: [
                    {
                        required: true,
                        message: '请选择行政区划',
                        trigger: 'blur',
                    },
                ],
                squareTeamList: [
                    {
                        required: true,
                        validator: validateSquare,
                        tirgger: 'change',
                    },
                ],
            },
            type: '新增',
            formData: {
                squareTeamList: [],
            },
            areaCode: [],
            btnLoading: false,
            options: [],
        }
    },
    created() {
        this.getTownTree()
    },
    methods: {
        getTownTree() {
            Team.townTree({}, (res) => {
                if (res.state) {
                    this.options = res.value
                }
            })
        },
        open(data) {
            this.formData = {
                squareTeamList: [],
            }
            this.visible = true
            this.type = '新增'
        },
        edit(id) {
            this.formData = {}
            this.visible = true
            this.type = '编辑'
            Personal.detailId(id, (res) => {
                this.formData = res
                this.areaCode = res.areaFullCode
                    ? res.areaFullCode.split('/').splice(1)
                    : []
                console.log(this.areaCode)
            })
        },
        handleClose() {
            this.visible = false
        },
        resetForm(formName) {
            this.$refs.form.resetFields()
        },
        handleChange(val) {
            let arr = JSON.parse(JSON.stringify(val))
            this.formData.areaFullCode = '/' + arr.join('/')
            this.formData.areaCode = arr.pop()
        },
        //保存
        handleSave() {
            this.$refs.form.validate((valid) => {
                if (valid) {
                    this.btnLoading = true
                    let method
                    if (this.type === '新增') {
                        method = Personal.addSave
                    } else {
                        method = Personal.upData
                    }
                    console.log(this.formData)

                    method(this.formData, (response) => {
                        if (response.state) {
                            this.$notify({
                                type: 'success',
                                message: this.type + '成功',
                                duration: 2000,
                            })
                            this.handleClose()
                            this.$emit('getData')
                        } else {
                            this.$message.warning(response.message)
                        }
                        this.btnLoading = false
                    })
                } else {
                    this.$notify({
                        type: 'warning',
                        message: '请完善表单信息！',
                        duration: 2000,
                    })
                }
            })
        },
        handleSearchPlaces() {
            this.$refs.placesDialog.open(this.formData.squareTeamList)
        },
        changePlaces(data) {
            console.log(data)
            this.formData.squareTeamList = data
        },
    },
}
</script>

<style lang="scss" scoped>
/deep/ .square-select {
    display: none;
}
/deep/.el-dialog__wrapper {
    overflow: hidden;
}

.dialog-footer {
    display: flex;
    justify-content: flex-end;
}

//加载遮罩
/deep/.el-dialog__body {
    box-sizing: border-box;

    .el-loading-parent--relative {
        max-height: inherit;
    }
}
</style>